Hi there!

I really enjoy OpenFisca, but I recently encountered an issue.

### Here is what I did:


### Here is what I expected to happen:


### Here is what actually happened:


### Here is data (or links to it) that can help you reproduce this issue:



## Context

I identify more as a:

- Analyst _(I make macroscopic computations on real populations)_.
- Business expert _(I create tests and model legislation)_.
- Commenter _(I make data visualisations)_.
- Developer _(I create tools that use the existing OpenFisca code)_.
- Historian _(I accumulate data based on past legislation values)_.
- Lobbyist _(I model reforms to make them exist)_.
- Producer _(I make computations on individual situations)_.

(remove this line as well as all items in the list that don't fit your situation)
